# YATLA 📑: Yet Another Templating Language (Again!)

YATLA is a templating engine with a simple templating language specifically designed for type inference, allowing consumers to provide users with slots of determined types.

## Roadmap 🗺️

- [x] Add numerical blocks
- [x] Add type inference. Go from a template -> list of typed parameters
- [x] Write own lexer to respect whitespace
- [x] Write own own parsing system
- [x] Add template validation (preventing non-unique identifiers...)
- [x] Publish as pip-installable package
- [x] Add foreach loops
- [ ] Add numerical function calls (round, max, min...) (maybe not just numerical? string.capitalise?)
- [ ] Think about object accessors

## Contributing

Contributions are welcome! If you encounter any issues or have suggestions for improvement, please [submit an issue](https://github.com/eugene-prout/yatla/issues).

## License

This project is licensed under the MIT License - see the [LICENSE](/LICENSE) file for details.

## Acknowledgements

YATLA is developed and maintained by [Eugene Prout](https://www.prout.tech).